# insert string s in to the trie
def insert(trie, s):
    # go through the characters of s one at a time
    for c in s:
        # if there is edge exiting this trie node for character c
        # then create a new trie node
        if c not in trie[0]:
            trie[0][c] = [{}, False]
        # follow the character to get the next trie node
        trie = trie[0][c]
    # now trie is the final trie node we reached when processing s,
    # so indicate it represents a dictionary word
    trie[1] = True


# hits is a list (should intially be empty)
# afterward, for each 0 <= i < len(s) we have that
# hits[i] will be True if and only if the substring s[:i+1] is
# a name in the trie
def hit(trie, s, hits):
    for c in s:
        if c not in trie[0]: break
        trie = trie[0][c]
        hits.append(trie[1])
    hits += [False]*(len(s)-len(hits))


n, q = map(int, input().split())

# The forward and reverse tries.
# A trie node is represented as a list [ptrs, word]
#   where ptrs is a dictionary indexed by characters whose values
#   are the trie nodes we get by following that character.
#   word is a boolean indicating if the sequence of characters used to
#   get to this trie node is in fact a word in the dictionary.
fwd = [{}, False]
rev = [{}, False]

# read in the dictionary and construct the forward and reverse tries
for i in range(n):
    s = input()

    insert(fwd, s)
    insert(rev, s[::-1])

# process each query string
for i in range(q):
    s = input()
    fhit = []
    rhit = []

    # first see all indices i such that s[:i+1] is a name
    hit(fwd, s, fhit)

    # s itself is a name, then report it and continue
    if fhit[len(s)-1]:
        print("simple name")
        continue

    # now get all indices i such that s[i:] is a name in the dictionary
    hit(rev, s[::-1], rhit)

    # go through all indices to see if some i has both s[:i+1] and s[i:]
    # being in the dictionary
    comp = False
    for i in range(len(s)):
        if fhit[i] and rhit[len(s)-i-2]: # recall rhit was the hit[] list for the reverse of s
            comp = True
            print("compound name")
            break

    if not comp:
        print("unknown name")
