#!/opt/local/bin/python3.4

# cross product, also happens to be twice the area
# of the triangle with corners p, q, (0,0) if the p-q turn is ccw
def cross(p, q):
    return p.x*q.y - p.y*q.x

# is the turn from p to q about r ccw?
# positive for yes, negative for no, 0 for collinear
def ccw(p, q, r):
    return cross(p-r, q-r)

class point:
    def __init__(self, x, y):
        self.x, self.y = x, y

    def __sub__(self, rhs):
        return point(self.x - rhs.x, self.y - rhs.y)

    # is the shortest angle from self to rhs about the origin ccw?
    def __lt__(self, rhs):
        return cross(self, rhs) > 0

    # for debugging
    def __str__(self):
        return "(" + str(self.x) + "," + str(self.y) + ")"


def best_pt(q):
    n = len(q)
    if n < 2: return 0

    q.sort()

    vals = {}
    for i in range(n):
        for j in range(i):

            # ensure this is a valid triangle
            empty = True
            for k in range(j+1,i):
                empty &= ccw(q[j], q[i], q[k]) < 0
            if not empty:
                vals[(j,i)] = -1000000000
                continue

            val = 0
            for k in range(j):
                if ccw(q[k], q[i], q[j]) < 0:
                    val = max(val, vals[(k,j)])

            vals[(j,i)] = val + cross(q[j], q[i])

    return max(vals.values())

def solve(p):
    best = 0

    for orig in p:
        q = []
        for s in p:
            if s.y > orig.y or (s.y == orig.y and s.x > orig.x):
                q.append(s-orig)
        best = max(best, best_pt(q))
    return best

# begin execution
n = int(input())

p = []
for i in range(n):
    x,y = map(int, input().split())
    p.append(point(x,y))

print("{0:.1f}".format(solve(p)*0.5))
