# bags are the vertices in the tree, I use -1 for the third vertex in
# original bag to keep it simple (so all bags have size 3)
bags = [(-1,0,1)]

# ch[i] is the set of indices of children of bag[i] in the tree
ch = [set()]

# eb[e] is the bag that introduced edge e
# I assume that an edge (u,v) is queried in the form u < v
# if e is deleted in the deletion phase (i.e. the second part of the sample)
# then it will be removed from this dictionary
eb = {(0,1) : 0}

# x will be a binary number from 0 to 7 that indicates the set of
# vertices in the bag (a triple of vertices)
# returns the actual set() of vertices
def makeset(x, bag):
    s = set()
    for i in range(3):
        if x&(2**i): s.add(bag[i])
    return s

# given a subset of vertices "ind", will make sure no two of them are adjacent
# note, this will only be called with sets where len(ind) <= 3
def checkind(ind):
    for u in ind:
        for v in ind:
            if (u,v) in eb or (v,u) in eb:
                return False
    return True

# read the number of generation and deletion steps
n, m = map(int, input().split())

# now read process the generation steps
for i in range(n):
    u,v,w = map(int, input().split())

    # u,v is the edge we generate from, so get the bag that introduced it
    # and add this new bag (which will be put at index len(bags)) as a child
    ch[eb[(u,v)]].add(len(bags))

    # both uw and vw are introduced in this new bag
    eb[(u,w)] = len(bags)
    eb[(v,w)] = len(bags)

    # add the new bag now and make its child set intially empty
    bags.append((u,v,w))
    ch.append(set())

# now delete the edges in the second part of the input
for i in range(m):
    u,v = map(int, input().split())
    eb.pop((u,v)) # just remove the edge

# vals[i][x] will be f[S,I] from the editorial where S is the set of nodes
#   in bag[i] and I is a subset of S that is indicated by bitset/integer x.
# Note if x indicates a subset of S that is not independent, it will not
#   be a key in the dictionary vals[i].
# The final solution will be the largest value stored in some entry of vals[0],
#   minus 1 because the "extra" vertex -1 (see the start of the code) will be there
vals = [dict() for b in bags]

# Go throught the bags in reverse order, this will ensure when a bag is processed
#   then all of its children are already processed.
for i in range(len(bags)-1, -1, -1):
    for x in range(8): # go through each subset of bags[i]
        ind = makeset(x, bags[i]) # get the corresponding set of nodes
        if not checkind(ind): continue # if not an indpendent set, we are done

        vals[i][x] = len(ind) # count the nodes in ind
        for j in ch[i]: # go through each child of bags[i] in the tree
            y = 0    # y will be an indicator for a subset of bags[j]
            com = 0  # number of vertices in common with ind and each subset of bags[j] we will consider

            # if the last vertex of bags[i] is in ind, it must then be in the independent
            # subset of bags[j] so add it to the bitset y
            if bags[i][2] in ind:
                y += 2
                com += 1

            # check which of the other vertex of bags[i] corresponds to the edge
            # that generated bags[j] and add it to y if it is in ind
            if bags[i][0] in ind and bags[i][0] == bags[j][0]:
                y += 1
                com += 1
            if bags[i][1] in ind and bags[i][1] == bags[j][0]:
                y += 1
                com += 1

            # tmp will be the best value of independent subsets of nodes lying
            # at or below bags[j] that is consistent with ind
            tmp = vals[j][y]

            # now try adding the new vertex of bags[j], if it still gives
            # an independent subset then see if, recursively, it yields
            # a bigger independent set than without using the new vertex
            if y+4 in vals[j]: tmp = max(tmp, vals[j][y+4])

            # now add this to the sum in the recurrence for vals[i][x]
            # (equivalently, the corresponding f[S,I] from the editorial)
            vals[i][x] += tmp - com

# remember to subtract 1 as the best independent set will include the
# ficticious node -1
print(max(vals[0].values()) - 1)
